Documentation
¶
Index ¶
- type BridgeLister
- type BridgeListerExpansion
- type BridgeNamespaceLister
- type BridgeNamespaceListerExpansion
- type JQTransformationLister
- type JQTransformationListerExpansion
- type JQTransformationNamespaceLister
- type JQTransformationNamespaceListerExpansion
- type SynchronizerLister
- type SynchronizerListerExpansion
- type SynchronizerNamespaceLister
- type SynchronizerNamespaceListerExpansion
- type TransformationLister
- type TransformationListerExpansion
- type TransformationNamespaceLister
- type TransformationNamespaceListerExpansion
- type XMLToJSONTransformationLister
- type XMLToJSONTransformationListerExpansion
- type XMLToJSONTransformationNamespaceLister
- type XMLToJSONTransformationNamespaceListerExpansion
- type XSLTTransformationLister
- type XSLTTransformationListerExpansion
- type XSLTTransformationNamespaceLister
- type XSLTTransformationNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BridgeLister ¶ added in v0.1.14
type BridgeLister interface {
// List lists all Bridges in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Bridge, err error)
// Bridges returns an object that can list and get Bridges.
Bridges(namespace string) BridgeNamespaceLister
BridgeListerExpansion
}
BridgeLister helps list Bridges. All objects returned here must be treated as read-only.
func NewBridgeLister ¶ added in v0.1.14
func NewBridgeLister(indexer cache.Indexer) BridgeLister
NewBridgeLister returns a new BridgeLister.
type BridgeListerExpansion ¶ added in v0.1.14
type BridgeListerExpansion interface{}
BridgeListerExpansion allows custom methods to be added to BridgeLister.
type BridgeNamespaceLister ¶ added in v0.1.14
type BridgeNamespaceLister interface {
// List lists all Bridges in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Bridge, err error)
// Get retrieves the Bridge from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Bridge, error)
BridgeNamespaceListerExpansion
}
BridgeNamespaceLister helps list and get Bridges. All objects returned here must be treated as read-only.
type BridgeNamespaceListerExpansion ¶ added in v0.1.14
type BridgeNamespaceListerExpansion interface{}
BridgeNamespaceListerExpansion allows custom methods to be added to BridgeNamespaceLister.
type JQTransformationLister ¶
type JQTransformationLister interface {
// List lists all JQTransformations in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.JQTransformation, err error)
// JQTransformations returns an object that can list and get JQTransformations.
JQTransformations(namespace string) JQTransformationNamespaceLister
JQTransformationListerExpansion
}
JQTransformationLister helps list JQTransformations. All objects returned here must be treated as read-only.
func NewJQTransformationLister ¶
func NewJQTransformationLister(indexer cache.Indexer) JQTransformationLister
NewJQTransformationLister returns a new JQTransformationLister.
type JQTransformationListerExpansion ¶
type JQTransformationListerExpansion interface{}
JQTransformationListerExpansion allows custom methods to be added to JQTransformationLister.
type JQTransformationNamespaceLister ¶
type JQTransformationNamespaceLister interface {
// List lists all JQTransformations in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.JQTransformation, err error)
// Get retrieves the JQTransformation from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.JQTransformation, error)
JQTransformationNamespaceListerExpansion
}
JQTransformationNamespaceLister helps list and get JQTransformations. All objects returned here must be treated as read-only.
type JQTransformationNamespaceListerExpansion ¶
type JQTransformationNamespaceListerExpansion interface{}
JQTransformationNamespaceListerExpansion allows custom methods to be added to JQTransformationNamespaceLister.
type SynchronizerLister ¶
type SynchronizerLister interface {
// List lists all Synchronizers in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Synchronizer, err error)
// Synchronizers returns an object that can list and get Synchronizers.
Synchronizers(namespace string) SynchronizerNamespaceLister
SynchronizerListerExpansion
}
SynchronizerLister helps list Synchronizers. All objects returned here must be treated as read-only.
func NewSynchronizerLister ¶
func NewSynchronizerLister(indexer cache.Indexer) SynchronizerLister
NewSynchronizerLister returns a new SynchronizerLister.
type SynchronizerListerExpansion ¶
type SynchronizerListerExpansion interface{}
SynchronizerListerExpansion allows custom methods to be added to SynchronizerLister.
type SynchronizerNamespaceLister ¶
type SynchronizerNamespaceLister interface {
// List lists all Synchronizers in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Synchronizer, err error)
// Get retrieves the Synchronizer from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Synchronizer, error)
SynchronizerNamespaceListerExpansion
}
SynchronizerNamespaceLister helps list and get Synchronizers. All objects returned here must be treated as read-only.
type SynchronizerNamespaceListerExpansion ¶
type SynchronizerNamespaceListerExpansion interface{}
SynchronizerNamespaceListerExpansion allows custom methods to be added to SynchronizerNamespaceLister.
type TransformationLister ¶
type TransformationLister interface {
// List lists all Transformations in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Transformation, err error)
// Transformations returns an object that can list and get Transformations.
Transformations(namespace string) TransformationNamespaceLister
TransformationListerExpansion
}
TransformationLister helps list Transformations. All objects returned here must be treated as read-only.
func NewTransformationLister ¶
func NewTransformationLister(indexer cache.Indexer) TransformationLister
NewTransformationLister returns a new TransformationLister.
type TransformationListerExpansion ¶
type TransformationListerExpansion interface{}
TransformationListerExpansion allows custom methods to be added to TransformationLister.
type TransformationNamespaceLister ¶
type TransformationNamespaceLister interface {
// List lists all Transformations in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Transformation, err error)
// Get retrieves the Transformation from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Transformation, error)
TransformationNamespaceListerExpansion
}
TransformationNamespaceLister helps list and get Transformations. All objects returned here must be treated as read-only.
type TransformationNamespaceListerExpansion ¶
type TransformationNamespaceListerExpansion interface{}
TransformationNamespaceListerExpansion allows custom methods to be added to TransformationNamespaceLister.
type XMLToJSONTransformationLister ¶
type XMLToJSONTransformationLister interface {
// List lists all XMLToJSONTransformations in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.XMLToJSONTransformation, err error)
// XMLToJSONTransformations returns an object that can list and get XMLToJSONTransformations.
XMLToJSONTransformations(namespace string) XMLToJSONTransformationNamespaceLister
XMLToJSONTransformationListerExpansion
}
XMLToJSONTransformationLister helps list XMLToJSONTransformations. All objects returned here must be treated as read-only.
func NewXMLToJSONTransformationLister ¶
func NewXMLToJSONTransformationLister(indexer cache.Indexer) XMLToJSONTransformationLister
NewXMLToJSONTransformationLister returns a new XMLToJSONTransformationLister.
type XMLToJSONTransformationListerExpansion ¶
type XMLToJSONTransformationListerExpansion interface{}
XMLToJSONTransformationListerExpansion allows custom methods to be added to XMLToJSONTransformationLister.
type XMLToJSONTransformationNamespaceLister ¶
type XMLToJSONTransformationNamespaceLister interface {
// List lists all XMLToJSONTransformations in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.XMLToJSONTransformation, err error)
// Get retrieves the XMLToJSONTransformation from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.XMLToJSONTransformation, error)
XMLToJSONTransformationNamespaceListerExpansion
}
XMLToJSONTransformationNamespaceLister helps list and get XMLToJSONTransformations. All objects returned here must be treated as read-only.
type XMLToJSONTransformationNamespaceListerExpansion ¶
type XMLToJSONTransformationNamespaceListerExpansion interface{}
XMLToJSONTransformationNamespaceListerExpansion allows custom methods to be added to XMLToJSONTransformationNamespaceLister.
type XSLTTransformationLister ¶
type XSLTTransformationLister interface {
// List lists all XSLTTransformations in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.XSLTTransformation, err error)
// XSLTTransformations returns an object that can list and get XSLTTransformations.
XSLTTransformations(namespace string) XSLTTransformationNamespaceLister
XSLTTransformationListerExpansion
}
XSLTTransformationLister helps list XSLTTransformations. All objects returned here must be treated as read-only.
func NewXSLTTransformationLister ¶
func NewXSLTTransformationLister(indexer cache.Indexer) XSLTTransformationLister
NewXSLTTransformationLister returns a new XSLTTransformationLister.
type XSLTTransformationListerExpansion ¶
type XSLTTransformationListerExpansion interface{}
XSLTTransformationListerExpansion allows custom methods to be added to XSLTTransformationLister.
type XSLTTransformationNamespaceLister ¶
type XSLTTransformationNamespaceLister interface {
// List lists all XSLTTransformations in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.XSLTTransformation, err error)
// Get retrieves the XSLTTransformation from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.XSLTTransformation, error)
XSLTTransformationNamespaceListerExpansion
}
XSLTTransformationNamespaceLister helps list and get XSLTTransformations. All objects returned here must be treated as read-only.
type XSLTTransformationNamespaceListerExpansion ¶
type XSLTTransformationNamespaceListerExpansion interface{}
XSLTTransformationNamespaceListerExpansion allows custom methods to be added to XSLTTransformationNamespaceLister.